// src/components.tsx
import React, {
  createContext,
  useContext,
  useId,
  useMemo,
  useRef
} from "react";

// src/useCodeSpotlight.ts
var useCodeSpotlight = () => {
  const { id, mode, ref } = useCodeSpotlightContext();
  const focusTarget = (target) => {
    const codeBlock = ref?.current;
    if (!codeBlock) return;
    codeBlock.setAttribute("data-hovered", "true");
    const tokens = codeBlock.querySelectorAll("span");
    tokens.forEach((token) => {
      if (mode === "equal" && token.textContent === target) {
        token.classList.add("spotlight-target");
      } else if (mode === "include" && token.textContent?.includes(target)) {
        token.classList.add("spotlight-target");
      } else {
        token.classList.remove("spotlight-target");
      }
    });
  };
  const unfocusTarget = () => {
    const codeBlock = ref?.current;
    if (!codeBlock) return;
    codeBlock.setAttribute("data-hovered", "false");
    const tokens = codeBlock.querySelectorAll("span");
    tokens.forEach((token) => {
      token.classList.remove("spotlight-target");
    });
  };
  return { id, focusTarget, unfocusTarget };
};

// src/components.tsx
import { jsx } from "react/jsx-runtime";
var CodeSpotlightContext = createContext({
  ref: null,
  id: "",
  mode: "equal"
});
function useCodeSpotlightContext() {
  const context = useContext(CodeSpotlightContext);
  if (!context) {
    console.error(
      "[code-spotlight] useCodeSpotlight must be used within a CodeSpotlightProvider"
    );
  }
  return context;
}
function CodeSpotlight({
  children,
  mode = "include"
}) {
  const preRef = useRef(null);
  const id = useId();
  const value = useMemo(() => ({ id, mode, ref: preRef }), [id, mode, preRef]);
  return /* @__PURE__ */ jsx(CodeSpotlightContext.Provider, { value, children: React.Children.map(children, (child) => {
    if (typeof child === "object" && child !== null && "type" in child && child.type === "pre") {
      return React.cloneElement(child, {
        id,
        className: child.props && typeof child.props === "object" && "className" in child.props ? `${child.props.className} code-spotlight-container` : "code-spotlight-container",
        ref: preRef
      });
    }
    return child;
  }) });
}
function CodeSpotlightTrigger({
  children,
  target
}) {
  const { focusTarget, unfocusTarget } = useCodeSpotlight();
  return /* @__PURE__ */ jsx(
    "code",
    {
      className: "code-spotlight-trigger",
      onMouseEnter: () => focusTarget(target),
      onMouseLeave: unfocusTarget,
      children
    }
  );
}
CodeSpotlight.Trigger = CodeSpotlightTrigger;
export {
  CodeSpotlight,
  CodeSpotlightTrigger,
  useCodeSpotlight,
  useCodeSpotlightContext
};
